<?php
/*
 * Plugin Name: VS Website Closed
 * Description: This is a lightweight plugin to close your website on selected days of the week.
 * Version: 2.2
 * Author: Guido
 * Author URI: https://www.guido.site
 * License: GNU General Public License v3
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain: very-simple-website-closed
 */

// disable direct access
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// enqueue colorpicker script
function vswc_enqueue_color_picker() {
	wp_enqueue_style( 'wp-color-picker' );
	wp_enqueue_script( 'vswc_colorpicker_script', plugins_url('/js/vswc-colorpicker.js', __FILE__ ), array( 'wp-color-picker' ), false, true );
}
add_action( 'admin_enqueue_scripts', 'vswc_enqueue_color_picker' );

// add settings link
function vswc_action_links( $links ) {
	$settingslink = array( '<a href="'.admin_url( 'options-general.php?page=vswc' ).'">'.__('Settings', 'very-simple-website-closed').'</a>', );
	return array_merge( $links, $settingslink );
}
add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), 'vswc_action_links' );

// create closed page
function vswc_template() {
	// variables
	$vswc_today = current_datetime()->getTimestamp();
	$vswc_day = wp_date('w', $vswc_today);
	$vswc_preview = get_option( 'vswc-setting-1' );
	$vswc_exclude_admin = get_option( 'vswc-setting-15' );
	$vswc_monday = get_option( 'vswc-setting-2' );
	$vswc_tuesday = get_option( 'vswc-setting-3' );
	$vswc_wednesday = get_option( 'vswc-setting-4' );
	$vswc_thursday = get_option( 'vswc-setting-5' );
	$vswc_friday = get_option( 'vswc-setting-6' );
	$vswc_saturday = get_option( 'vswc-setting-7' );
	$vswc_sunday = get_option( 'vswc-setting-8' );
	$vswc_title = get_option( 'vswc-setting-13' );
	$vswc_content = get_option( 'vswc-setting-14' );
	$vswc_preview_notice = __( 'Preview mode', 'very-simple-website-closed' );
	$vswc_background = empty( get_option( 'vswc-setting-9' ) ) ? '#fff' : get_option( 'vswc-setting-9' );
	$vswc_color_title = empty( get_option( 'vswc-setting-20' ) ) ? '#333' : get_option( 'vswc-setting-20' );
	$vswc_color = empty( get_option( 'vswc-setting-10' ) ) ? '#333' : get_option( 'vswc-setting-10' );
	$vswc_align = empty( get_option( 'vswc-setting-11' ) ) ? 'left' : get_option( 'vswc-setting-11' );
	$vswc_font_size_title = get_option( 'vswc-setting-18' );
	$vswc_font_size = get_option( 'vswc-setting-19' );
	$vswc_logo_id = get_option( 'vswc-setting-12' );
	$vswc_logo = wp_get_attachment_image_src($vswc_logo_id, 'full');
	$vswc_logo_width = get_option( 'vswc-setting-17' );
	$vswc_logo_alt = get_bloginfo( 'name' );
	$vswc_custom_css = get_option( 'vswc-setting-21' );
	if ( empty($vswc_font_size_title) || !is_numeric($vswc_font_size_title) ) {
		$vswc_font_size_title = 32;
	}
	if ( empty($vswc_font_size) || !is_numeric($vswc_font_size) ) {
		$vswc_font_size = 16;
	}
	if ( empty($vswc_logo_width) || !is_numeric($vswc_logo_width) ) {
		$vswc_logo_width = 200;
	}
	if ( empty($vswc_title) ) {
		$vswc_title = __( 'Closed', 'very-simple-website-closed' );
	}
	if ( empty($vswc_content) ) {
		$vswc_content = __( 'Website is closed today.', 'very-simple-website-closed' );
	}
	// template begin
	if ( ( ($vswc_preview == 'yes') && current_user_can( 'manage_options' ) ) || ($vswc_sunday == 'yes' && $vswc_day == '0') || ($vswc_monday == 'yes' && $vswc_day == '1') || ($vswc_tuesday == 'yes' && $vswc_day == '2') || ($vswc_wednesday == 'yes' && $vswc_day == '3') || ($vswc_thursday == 'yes' && $vswc_day == '4') || ($vswc_friday == 'yes' && $vswc_day == '5') || ($vswc_saturday == 'yes' && $vswc_day == '6') ) {
		if ( ($vswc_preview != 'yes') && ($vswc_exclude_admin == 'yes') && current_user_can( 'manage_options' ) ) {
			return;
		} else {
			// 503 header begin
			$protocol = 'HTTP/1.0';
			if ( $_SERVER['SERVER_PROTOCOL'] === 'HTTP/1.1' ) {
				$protocol = 'HTTP/1.1';
			}
			header( $protocol . ' 503 Service Unavailable', true, 503 );
			// 503 header end
			?>
			<!doctype html>
			<html>
			<head>
			<meta name="viewport" content="width=device-width, initial-scale=1">
			<title><?php echo esc_attr($vswc_title); ?></title>
			<?php
			// styling begin
			wp_enqueue_style('vswc_style', plugins_url('/css/vswc-style.min.css',__FILE__));
			wp_print_styles('vswc_style'); ?>
			<style type="text/css">body {background:<?php echo esc_attr($vswc_background); ?>;color:<?php echo esc_attr($vswc_color); ?>;font-size:<?php echo esc_attr($vswc_font_size); ?>px;text-align:<?php echo esc_attr($vswc_align); ?>;}h1.vswc-title {color:<?php echo esc_attr($vswc_color_title); ?>;font-size:<?php echo esc_attr($vswc_font_size_title); ?>px;}</style>
			<?php if ( !empty($vswc_custom_css) ) { ?>
			<style type="text/css"><?php echo wp_strip_all_tags($vswc_custom_css, true); ?></style>
			<?php }
			// styling end
			?>
			</head>
			<body>
			<?php
			// page content begin
			?>
			<div id="vswc" class="vswc">
				<?php
				if (!empty($vswc_logo)) {
					echo '<img class="vswc-logo" src="'.esc_url($vswc_logo[0]).'" width="'.esc_attr($vswc_logo_width).'" alt="'.esc_attr($vswc_logo_alt).'"/>';
				}
				echo '<h1 class="vswc-title">'.esc_attr($vswc_title).'</h1>';
				echo '<div class="vswc-content">'.wpautop(wp_kses_post($vswc_content)).'</div>';
				if ( ($vswc_preview == 'yes') && current_user_can( 'manage_options' ) ) {
					echo '<div class="vswc-preview-notice">'.esc_attr($vswc_preview_notice).'</div>';
				}
				?>
			</div>
			<?php
			// page content end
			?>
			</body>
			</html>
			<?php
			exit;
		}
	}
	// template end
}
add_action( 'template_redirect', 'vswc_template' );

// include options file
include 'vswc-options.php';
